@@ -14,17 +14,13 @@ setMethod("optRisk", signature(model = "InfRobModel", risk = "asRisk"),
              z.start = NULL, A.start = NULL, upper = 1e4, 
              maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, noLow = FALSE){
         L2derivDim <- numberOfMaps(model@center@L2deriv)
-        ow <- options("warn")
-        on.exit(options(ow))
         if(L2derivDim == 1){
-            options(warn = -1)
             res <- getInfRobIC(L2deriv = model@center@L2derivDistr[[1]], 
                         neighbor = model@neighbor, risk = risk,
                         symm = model@center@L2derivDistrSymm[[1]],
                         Finfo = model@center@FisherInfo, trafo = trafo(model@center@param), 
                         upper = upper, maxiter = maxiter, tol = tol, warn = warn,
                         noLow = noLow)
-            options(ow)     
             return(res$risk)
         }else{
             if(is(model@center@distribution, "UnivariateDistribution")){
@@ -48,14 +44,12 @@ setMethod("optRisk", signature(model = "InfRobModel", risk = "asRisk"),
                     }
                 }
 
-                options(warn = -1)
                 res <- getInfRobIC(L2deriv = L2deriv, neighbor = model@neighbor, 
                             risk = risk, Distr = model@center@distribution, 
                             DistrSymm = model@center@distrSymm, L2derivSymm = L2derivSymm,
                             L2derivDistrSymm = L2derivDistrSymm, Finfo = model@center@FisherInfo, 
                             trafo = trafo(model@center@param), z.start = z.start, A.start = A.start, 
                             upper = upper, maxiter = maxiter, tol = tol, warn = warn)
-                options(ow)     
                 return(res$risk)
             }else{
                 stop("not yet implemented")
@@ -69,17 +63,13 @@ setMethod("optRisk", signature(model = "InfRobModel", risk = "asRisk"),
 setMethod("optRisk", signature(model = "FixRobModel", risk = "fiUnOvShoot"),
     function(model, risk, sampleSize, upper = 1e4, maxiter = 50, 
              tol = .Machine$double.eps^0.4, warn = TRUE, Algo = "A", cont = "left"){
-        ow <- options("warn")
-        on.exit(options(ow))
         if(!identical(all.equal(sampleSize, trunc(sampleSize)), TRUE))
             stop("'sampleSize' has to be an integer > 0")
         if(is(model@center@distribution, "UnivariateDistribution")){
-            options(warn = -1)
             res <- getFixRobIC(Distr = model@center@distribution, 
                         neighbor = model@neighbor, risk = risk, 
                         sampleSize = sampleSize, upper = upper, maxiter = maxiter, 
                         tol = tol, warn = warn, Algo = Algo, cont = cont)
-            options(ow)             
             res$info <- c("optIC", res$info)
             return(res$risk)
         }else{
